# AutoEFT Model Files

This folder contains AutoEFT *model files* for various low-energy scenarios related to the Standard Model (**SM**).

## Models
| model         | file                           | fermion generations | comments |
|---------------|--------------------------------|--------------------:|----------|
| **SMEFT**     | [sm](sm.yml)                   | 3                   | default **SM** file
| **SMEFT**     | [all-left_sm](all-left_sm.yml) | 3                   | **SM** in the *all-left* chirality convention
| **SMEFT**     | [dynkin_sm](dynkin_sm.yml)     | 3                   | **SM** with *SU(N)* representations characterized by *Dynkin labels*
| **SMEFT**     | [nf1_sm](nf1_sm.yml)           | 1                   | **SM** with one generation of fermions
| **SMEFT**     | [bno_sm](bno_sm.yml)           | 3                   | **SM** with baryon number conservation
| **SMEFT**     | [bno_nf1_sm](bno_nf1_sm.yml)   | 1                   | **SM** with baryon number conservation and one generation of fermions
| **MFV-SMEFT** | [mfv-sm](mfv-sm.yml)           | 3                   | **SM** with additional *U(3)<sup>5</sup>* flavor symmetry
| **GRSMEFT**   | [grsm](grsm.yml)               | 3                   | **SM** including gravitational interactions
